OiRA

Help

1. Preparação
2. Envolvimento
3. Identificação + Avaliação
4. Plano de Ação
5. Relatório
6. Estado 0%

# Relatório

Agora que acabou de avaliar todos os riscos na sua organização e de ter criado um plano de ação, pode criar um relatório que lista todos os seus resultados. Pode, se pretendido, adicionar alguns comentários extra que devem ser incluídos neste relatório no campo em baixo.

Guardar e continuar

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More